@@ -5,12 +5,24 @@ import logging
 from invoke import run
 from docly.ioutils import CACHE_DIR, cache_exists, make_cache_dir
 
+try:
+    import jupytext
+    JUPYTEXT_AVAILABLE = True
+except Exception:
+    JUPYTEXT_AVAILABLE = False
+
 
 IPYNB_TO_PY_CMD = "jupytext --set-formats ipynb,py:percent"
 PY_TO_IPYNB_CMD = "jupytext --update --to ipynb"
 
 
 def convert_ipynb_to_python(notebook_path: Path):
+    if JUPYTEXT_AVAILABLE:
+        try:
+            jupytext.read(notebook_path.absolute())
+        except Exception:
+            return None
+
     actual_file_path = str(notebook_path.absolute())
     cache_file_name = actual_file_path[1:].replace("/", "#")
 
@@ -23,8 +35,9 @@ def convert_ipynb_to_python(notebook_path: Path):
     shutil.copy(actual_file_path, str(CACHE_DIR / cache_file_name))
 
     result = run(f"{IPYNB_TO_PY_CMD} {str(notebook_path.absolute())}", hide=True, warn=True)
+    
     if not result.ok:
-        logging.error("Could not run the conversion command. Maybe use `pip install 'docly[jupyter]'")
+        logging.error("Could not run the conversion command. Are you using an old version of Jupyter notebook? Otherwise, Maybe use `pip install 'docly[jupyter]'")
         return None
     else:
         return (notebook_path.absolute().parent / (notebook_path.stem + '.py')).absolute()
