@@ -21,4 +21,18 @@ def make_example(code_tokens):
                     source=" ".join(ct),
                     target="")
         examples.append(ex)
-    return examples
\ No newline at end of file
+    return examples
+
+
+class NewExample(object):
+
+    def __init__(self,
+                 source,
+                 target
+                 ):
+        self.source = source
+        self.target = target
+
+
+def make_new_example(code):
+    return [NewExample(source=code, target=None)]
